"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.networkToChannelMap = exports.networkChannelToChain = exports.networkChainToChannelId = exports.cosmwasmNetworkChainToRestUrls = exports.nativeDenomToChain = exports.chainToNativeDenoms = exports.addressPrefixToChain = exports.chainToAddressPrefix = exports.cosmwasmNetworkChainToChainId = exports.cosmwasmChainIdToNetworkChainPair = exports.IBC_TIMEOUT_MILLIS = exports.IBC_PACKET_CONN = exports.IBC_PACKET_DATA = exports.IBC_PACKET_SEQ = exports.IBC_PACKET_DST_PORT = exports.IBC_PACKET_SRC_PORT = exports.IBC_PACKET_SRC = exports.IBC_PACKET_DST = exports.IBC_PACKET_RECEIVE = exports.IBC_PACKET_SEND = exports.IBC_TRANSFER_PORT = exports.IBC_MSG_TYPE = exports.MSG_EXECUTE_CONTRACT_TYPE_URL = void 0;
const connect_sdk_1 = require("@wormhole-foundation/connect-sdk");
exports.MSG_EXECUTE_CONTRACT_TYPE_URL = "/cosmwasm.wasm.v1.MsgExecuteContract";
exports.IBC_MSG_TYPE = "/ibc.applications.transfer.v1.MsgTransfer";
exports.IBC_TRANSFER_PORT = "transfer";
// IBC Message Event type
exports.IBC_PACKET_SEND = "send_packet";
exports.IBC_PACKET_RECEIVE = "recv_packet";
// Attributes for IBC Packet Event
exports.IBC_PACKET_DST = "packet_dst_channel";
exports.IBC_PACKET_SRC = "packet_src_channel";
exports.IBC_PACKET_SRC_PORT = "packet_src_port";
exports.IBC_PACKET_DST_PORT = "packet_dst_port";
exports.IBC_PACKET_SEQ = "packet_sequence";
exports.IBC_PACKET_DATA = "packet_data";
exports.IBC_PACKET_CONN = "packet_connection";
exports.IBC_TIMEOUT_MILLIS = 10 * 60 * 1000; // 10 minutes
const networkChainCosmwasmChainIds = [
    [
        "Mainnet",
        [
            ["Cosmoshub", "cosmoshub-4"],
            ["Evmos", "evmos_9001-2"],
            ["Injective", "injective-1"],
            ["Osmosis", "osmosis-1"],
            ["Sei", "pacific-1"],
            ["Terra", "columbus-5"],
            ["Terra2", "phoenix-1"],
            ["Wormchain", "wormchain"],
            ["Xpla", "dimension_37-1"],
        ],
    ],
    [
        "Testnet",
        [
            ["Cosmoshub", "theta-testnet-001"],
            ["Evmos", "evmos_9000-4"],
            ["Injective", "injective-888"],
            ["Osmosis", "osmo-test-5"],
            ["Sei", "atlantic-2"],
            ["Terra2", "pisco-1"],
            ["Wormchain", "wormchain-testnet-0"],
            ["Xpla", "cube_47-5"],
        ],
    ],
    ["Devnet", []],
];
exports.cosmwasmChainIdToNetworkChainPair = (0, connect_sdk_1.constMap)(networkChainCosmwasmChainIds, [2, [0, 1]]);
exports.cosmwasmNetworkChainToChainId = (0, connect_sdk_1.constMap)(networkChainCosmwasmChainIds);
const cosmwasmAddressPrefix = [
    ["Cosmoshub", "cosmos"],
    ["Evmos", "evmos"],
    ["Injective", "inj"],
    ["Kujira", "kuji"],
    ["Osmosis", "osmo"],
    ["Sei", "sei"],
    ["Terra", "terra"],
    ["Terra2", "terra"],
    ["Wormchain", "wormhole"],
    ["Xpla", "xpla"], // TODO: make sure this is right
];
exports.chainToAddressPrefix = (0, connect_sdk_1.constMap)(cosmwasmAddressPrefix);
exports.addressPrefixToChain = (0, connect_sdk_1.constMap)(cosmwasmAddressPrefix, [1, [0]]);
const cosmwasmNativeDenom = [
    [
        "Mainnet",
        [
            ["Cosmoshub", "uatom"],
            ["Evmos", "aevmos"],
            ["Injective", "inj"],
            ["Kujira", "kuji"],
            ["Osmosis", "uosmo"],
            ["Sei", "usei"],
            ["Terra", "ulunah"],
            ["Terra2", "uluna"],
            ["Wormchain", "uworm"],
            ["Xpla", "uxpla"],
        ],
    ],
    [
        "Testnet",
        [
            ["Cosmoshub", "uatom"],
            ["Evmos", "atevmos"],
            ["Injective", "inj"],
            ["Kujira", "kuji"],
            ["Osmosis", "uosmo"],
            ["Sei", "usei"],
            ["Terra", "ulunah"],
            ["Terra2", "uluna"],
            ["Wormchain", "uworm"],
            ["Xpla", "uxpla"],
        ],
    ],
];
exports.chainToNativeDenoms = (0, connect_sdk_1.constMap)(cosmwasmNativeDenom);
exports.nativeDenomToChain = (0, connect_sdk_1.constMap)(cosmwasmNativeDenom, [[0, 2], [1]]);
const cosmwasmNetworkChainRestUrl = [
    [
        "Mainnet",
        [
            ["Injective", "https://lcd.injective.network"],
            ["Evmos", "https://rest.bd.evmos.org:1317"],
        ],
    ],
    [
        "Testnet",
        [
            ["Injective", "https://k8s.testnet.lcd.injective.network"],
            ["Evmos", "https://rest.bd.evmos.dev:1317"],
        ],
    ],
    ["Devnet", []],
];
exports.cosmwasmNetworkChainToRestUrls = (0, connect_sdk_1.constMap)(cosmwasmNetworkChainRestUrl);
// IBC Channels from the perspective of Wormchain
const gatewayConnections = [
    [
        "Mainnet",
        [
            ["Cosmoshub", { srcChannel: "channel-5", dstChannel: "" }],
            ["Osmosis", { srcChannel: "channel-4", dstChannel: "" }],
        ],
    ],
    [
        "Testnet",
        [
            [
                "Cosmoshub",
                {
                    srcChannel: "channel-5",
                    dstChannel: "channel-3086",
                },
            ],
            [
                "Osmosis",
                {
                    srcChannel: "channel-9",
                    dstChannel: "channel-3906",
                },
            ],
        ],
    ],
    [
        "Devnet",
        [
            ["Cosmoshub", { srcChannel: "", dstChannel: "" }],
            ["Osmosis", { srcChannel: "", dstChannel: "" }],
        ],
    ],
];
exports.networkChainToChannelId = (0, connect_sdk_1.constMap)(gatewayConnections);
exports.networkChannelToChain = (0, connect_sdk_1.constMap)(gatewayConnections, [0, [2, 1]]);
exports.networkToChannelMap = (0, connect_sdk_1.constMap)(gatewayConnections, [0, [1, 2]]);
//# sourceMappingURL=constants.js.map