"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CosmwasmUtils = void 0;
const connect_sdk_1 = require("@wormhole-foundation/connect-sdk");
const constants_1 = require("./constants");
const platform_1 = require("./platform");
const address_1 = require("./address");
const stargate_1 = require("@cosmjs/stargate");
// forces CosmwasmUtils to implement PlatformUtils
var _ = CosmwasmUtils;
/**
 * @category CosmWasm
 */
// Provides runtime concrete value
var CosmwasmUtils;
(function (CosmwasmUtils) {
    function nativeTokenId(chain) {
        if (!isSupportedChain(chain))
            throw new Error(`invalid chain for CosmWasm: ${chain}`);
        return {
            chain: chain,
            // TODO
            // @ts-ignore
            address: new address_1.CosmwasmAddress(getNativeDenom(chain)),
        };
    }
    CosmwasmUtils.nativeTokenId = nativeTokenId;
    function isSupportedChain(chain) {
        const platform = (0, connect_sdk_1.chainToPlatform)(chain);
        return platform === platform_1.CosmwasmPlatform.platform;
    }
    CosmwasmUtils.isSupportedChain = isSupportedChain;
    function isNativeTokenId(chain, tokenId) {
        if (!isSupportedChain(chain))
            return false;
        if (tokenId.chain !== chain)
            return false;
        const native = nativeTokenId(chain);
        return native == tokenId;
    }
    CosmwasmUtils.isNativeTokenId = isNativeTokenId;
    async function getDecimals(chain, rpc, tokenId) {
        if (tokenId === "native" || isNativeTokenId(chain, tokenId))
            return (0, connect_sdk_1.nativeDecimals)(platform_1.CosmwasmPlatform.platform);
        const { decimals } = await rpc.queryContractSmart(tokenId.address.toString(), {
            token_info: {},
        });
        return decimals;
    }
    CosmwasmUtils.getDecimals = getDecimals;
    async function getBalance(chain, rpc, walletAddress, tokenId) {
        if (tokenId === "native") {
            const { amount } = await rpc.getBalance(walletAddress, getNativeDenom(chain));
            return BigInt(amount);
        }
        const { amount } = await rpc.getBalance(walletAddress, tokenId.address.toString());
        return BigInt(amount);
    }
    CosmwasmUtils.getBalance = getBalance;
    function getNativeDenom(chain) {
        // TODO: required because of const map
        if (platform_1.CosmwasmPlatform.network === "Devnet")
            throw new Error("No devnet native denoms");
        return (0, constants_1.chainToNativeDenoms)(platform_1.CosmwasmPlatform.network, chain);
    }
    function isNativeDenom(chain, denom) {
        return denom === getNativeDenom(chain);
    }
    CosmwasmUtils.isNativeDenom = isNativeDenom;
    async function sendWait(chain, rpc, stxns) {
        const txhashes = [];
        for (const stxn of stxns) {
            const result = await rpc.broadcastTx(stxn);
            txhashes.push(result.transactionHash);
        }
        return txhashes;
    }
    CosmwasmUtils.sendWait = sendWait;
    async function parseTransaction(chain, rpc, txid) {
        throw new Error("Not implemented");
        //const receipt = await rpc.getTransactionReceipt(txid);
        //if (receipt === null)
        //  throw new Error(`No transaction found with txid: ${txid}`);
        //const coreAddress = this.conf[chain]!.contracts.coreBridge;
        //const coreImpl = this.contracts.getCoreImplementationInterface();
        //return receipt.logs
        //  .filter((l: any) => {
        //    return l.address === coreAddress;
        //  })
        //  .map((log) => {
        //    const { topics, data } = log;
        //    const parsed = coreImpl.parseLog({ topics: topics.slice(), data });
        //    if (parsed === null) return undefined;
        //    const emitterAddress = this.parseAddress(chain, parsed.args.sender);
        //    return {
        //      chain: chain,
        //      emitter: emitterAddress.toUniversalAddress(),
        //      sequence: parsed.args.sequence,
        //    } as WormholeMessageId;
        //  })
        //  .filter(isWormholeMessageId);
    }
    CosmwasmUtils.parseTransaction = parseTransaction;
    async function getCurrentBlock(rpc) {
        return rpc.getHeight();
    }
    CosmwasmUtils.getCurrentBlock = getCurrentBlock;
    async function chainFromRpc(rpc) {
        const chainId = await rpc.getChainId();
        const networkChainPair = constants_1.cosmwasmChainIdToNetworkChainPair.get(chainId);
        if (networkChainPair === undefined)
            throw new Error(`Unknown Cosmwasm chainId ${chainId}`);
        const [network, chain] = networkChainPair;
        return [network, chain];
    }
    CosmwasmUtils.chainFromRpc = chainFromRpc;
    CosmwasmUtils.asQueryClient = (rpc) => {
        // @ts-ignore
        const tmClient = rpc.getTmClient();
        return stargate_1.QueryClient.withExtensions(tmClient, stargate_1.setupIbcExtension);
    };
})(CosmwasmUtils || (exports.CosmwasmUtils = CosmwasmUtils = {}));
//# sourceMappingURL=platformUtils.js.map