/**
 * @category Cosmwasm
 * Cosmwasm Contracts class. Contains methods for accessing ts interfaces for all available contracts
 */
export class CosmwasmContracts {
    _contracts;
    constructor(conf) {
        this._contracts = new Map();
        Object.entries(conf).forEach(([c, cfg]) => {
            this._contracts.set(c, cfg.contracts);
        });
    }
    getContracts(chain) {
        const contracts = this._contracts.get(chain);
        if (!contracts)
            throw new Error(`no Cosmwasm contracts found for ${chain}`);
        return contracts;
    }
    /**
     * Returns core wormhole contract for the chain
     *
     * @returns An interface for the core contract, errors if not found
     */
    getCore(chain, connection) {
        const address = this.getContracts(chain).coreBridge;
        if (!address)
            throw new Error(`Core contract for domain ${chain} not found`);
        return address;
    }
    /**
     * Returns wormhole bridge contract for the chain
     *
     * @returns An interface for the bridge contract, errors if not found
     */
    getTokenBridge(chain, connection) {
        const address = this.getContracts(chain).tokenBridge;
        if (!address)
            throw new Error(`Bridge contract for domain ${chain} not found`);
        return address;
    }
    /**
     * Returns wormhole NFT bridge contract for the chain
     *
     * @returns An interface for the NFT bridge contract, errors if not found
     */
    getNftBridge(chain, connection) {
        const address = this.getContracts(chain).nftBridge;
        if (!address)
            throw new Error(`NFT Bridge contract for domain ${chain} not found`);
        return address;
    }
    async getNativeWrapped(chain, connection) {
        throw new Error("Not implemented");
        // const address = toNative(
        //  chain,
        //  await this.getTokenBridge(chain, connection).WETH()
        // );
        // return { address, chain };
    }
}
//# sourceMappingURL=contracts.js.map