import { CosmWasmClient } from "@cosmjs/cosmwasm-stargate";
import { IbcExtension, QueryClient } from "@cosmjs/stargate";
import { ChainName, ChainsConfig, Network, TxHash, WormholeMessageId } from "@wormhole-foundation/connect-sdk";
import { CosmwasmChain } from "./chain";
import { IbcChannel } from "./constants";
import { CosmwasmContracts } from "./contracts";
import { Gateway } from "./gateway";
import { CosmwasmUtils } from "./platformUtils";
import { CosmwasmIbcBridge } from "./protocols/ibc";
import { CosmwasmTokenBridge } from "./protocols/tokenBridge";
import { CosmwasmChainName } from "./types";
/**
 * @category Cosmwasm
 */
export declare module CosmwasmPlatform {
    const platform = "Cosmwasm";
    let network: Network;
    let conf: ChainsConfig;
    let contracts: CosmwasmContracts;
    type Type = typeof platform;
    const nativeTokenId: typeof CosmwasmUtils.nativeTokenId, isNativeTokenId: typeof CosmwasmUtils.isNativeTokenId, isNativeDenom: typeof CosmwasmUtils.isNativeDenom, isSupportedChain: typeof CosmwasmUtils.isSupportedChain, getDecimals: typeof CosmwasmUtils.getDecimals, getBalance: typeof CosmwasmUtils.getBalance, sendWait: typeof CosmwasmUtils.sendWait, getCurrentBlock: typeof CosmwasmUtils.getCurrentBlock, chainFromRpc: typeof CosmwasmUtils.chainFromRpc;
    const getGatewayRpc: typeof Gateway.getRpc, getGatewayWrappedAsset: typeof Gateway.getWrappedAsset, gatewayAddress: typeof Gateway.gatewayAddress, getDestinationChannel: typeof Gateway.getDestinationChannel, getSourceChannel: typeof Gateway.getSourceChannel;
    function setConfig(network: Network, _conf?: ChainsConfig): typeof CosmwasmPlatform;
    function getRpc(chain: ChainName): Promise<CosmWasmClient>;
    function getChain(chain: ChainName): CosmwasmChain;
    function getNativeDenom(chain: ChainName): string;
    function parseTransaction(chain: ChainName, rpc: CosmWasmClient, txid: TxHash): Promise<WormholeMessageId[]>;
    function getTokenBridge(rpc: CosmWasmClient): Promise<CosmwasmTokenBridge>;
    function getIbcBridge(rpc: CosmWasmClient): Promise<CosmwasmIbcBridge>;
    const getQueryClient: (rpc: CosmWasmClient) => QueryClient & IbcExtension;
    const getIbcChannel: (chain: CosmwasmChainName) => IbcChannel | null;
}
//# sourceMappingURL=platform.d.ts.map