import { CosmWasmClient } from "@cosmjs/cosmwasm-stargate";
import { QueryClient, setupIbcExtension } from "@cosmjs/stargate";
import { DEFAULT_NETWORK, networkPlatformConfigs, } from "@wormhole-foundation/connect-sdk";
import { CosmwasmChain } from "./chain";
import { chainToNativeDenoms, networkChainToChannelId, } from "./constants";
import { CosmwasmContracts } from "./contracts";
import { Gateway } from "./gateway";
import { CosmwasmUtils } from "./platformUtils";
import { CosmwasmIbcBridge } from "./protocols/ibc";
import { CosmwasmTokenBridge } from "./protocols/tokenBridge";
var _ = CosmwasmPlatform;
/**
 * @category Cosmwasm
 */
export var CosmwasmPlatform;
(function (CosmwasmPlatform) {
    CosmwasmPlatform.platform = "Cosmwasm";
    CosmwasmPlatform.network = DEFAULT_NETWORK;
    CosmwasmPlatform.conf = networkPlatformConfigs(CosmwasmPlatform.network, CosmwasmPlatform.platform);
    CosmwasmPlatform.contracts = new CosmwasmContracts(CosmwasmPlatform.conf);
    // TODO: re-export all
    CosmwasmPlatform.nativeTokenId = CosmwasmUtils.nativeTokenId, CosmwasmPlatform.isNativeTokenId = CosmwasmUtils.isNativeTokenId, CosmwasmPlatform.isNativeDenom = CosmwasmUtils.isNativeDenom, CosmwasmPlatform.isSupportedChain = CosmwasmUtils.isSupportedChain, CosmwasmPlatform.getDecimals = CosmwasmUtils.getDecimals, CosmwasmPlatform.getBalance = CosmwasmUtils.getBalance, CosmwasmPlatform.sendWait = CosmwasmUtils.sendWait, CosmwasmPlatform.getCurrentBlock = CosmwasmUtils.getCurrentBlock, CosmwasmPlatform.chainFromRpc = CosmwasmUtils.chainFromRpc;
    CosmwasmPlatform.getGatewayRpc = Gateway.getRpc, CosmwasmPlatform.getGatewayWrappedAsset = Gateway.getWrappedAsset, CosmwasmPlatform.gatewayAddress = Gateway.gatewayAddress, CosmwasmPlatform.getDestinationChannel = Gateway.getDestinationChannel, CosmwasmPlatform.getSourceChannel = Gateway.getSourceChannel;
    function setConfig(network, _conf) {
        CosmwasmPlatform.conf = _conf ? _conf : networkPlatformConfigs(network, CosmwasmPlatform.platform);
        CosmwasmPlatform.contracts = new CosmwasmContracts(CosmwasmPlatform.conf);
        return CosmwasmPlatform;
    }
    CosmwasmPlatform.setConfig = setConfig;
    async function getRpc(chain) {
        const rpcAddress = CosmwasmPlatform.conf[chain].rpc;
        return await CosmWasmClient.connect(rpcAddress);
    }
    CosmwasmPlatform.getRpc = getRpc;
    function getChain(chain) {
        return new CosmwasmChain(chain);
    }
    CosmwasmPlatform.getChain = getChain;
    // TODO: should other platforms have something like this?
    function getNativeDenom(chain) {
        // TODO: required because of const map
        if (CosmwasmPlatform.network === "Devnet")
            throw new Error("No devnet native denoms");
        return chainToNativeDenoms(CosmwasmPlatform.network, chain);
    }
    CosmwasmPlatform.getNativeDenom = getNativeDenom;
    async function parseTransaction(chain, rpc, txid) {
        const tx = await rpc.getTx(txid);
        if (!tx)
            throw new Error("No Transaction found: " + txid);
        return [Gateway.getWormholeMessage(tx)];
    }
    CosmwasmPlatform.parseTransaction = parseTransaction;
    async function getTokenBridge(rpc) {
        return await CosmwasmTokenBridge.fromProvider(rpc, CosmwasmPlatform.contracts);
    }
    CosmwasmPlatform.getTokenBridge = getTokenBridge;
    async function getIbcBridge(rpc) {
        return await CosmwasmIbcBridge.fromProvider(rpc, CosmwasmPlatform.contracts);
    }
    CosmwasmPlatform.getIbcBridge = getIbcBridge;
    CosmwasmPlatform.getQueryClient = (rpc) => {
        // @ts-ignore
        const tmClient = rpc.getTmClient();
        return QueryClient.withExtensions(tmClient, setupIbcExtension);
    };
    // cached channels from config if available
    CosmwasmPlatform.getIbcChannel = (chain) => {
        return networkChainToChannelId.has(CosmwasmPlatform.network, chain)
            ? networkChainToChannelId.get(CosmwasmPlatform.network, chain)
            : null;
    };
})(CosmwasmPlatform || (CosmwasmPlatform = {}));
//# sourceMappingURL=platform.js.map